@@ -3,10 +3,17 @@
 #include <QtCore/QObject>
 #include <QtCore/qvariant.h>
 #include <QtGui/QApplication>
+#include <QtCore/QCoreApplication>
 #include <QtCore/QtGlobal>
 #include <QtLocation/QGeoPositionInfoSource>
 #include <QtLocation/QGeoSatelliteInfoSource>
 #include <QtLocation/QGeoCoordinate>
+
+extern "C" {
+#include <location/location-gps-device.h>
+#include <location/location-gpsd-control.h>
+}
+
 using namespace QtMobility;
 /*
 class aThread : public QThread
@@ -36,19 +43,17 @@ class QDialGPS : public QApplication
 	   double angle;
 	   double x;
 	   double y;
-//	   QGeoCoordinate goal;
-	   QGeoPositionInfoSource * m_location;
-	   QGeoSatelliteInfoSource * m_satellite;
-	   QGraphicsObject* view;
-//	   aThread *myThread;
+	   double z;
+	   double goalx;
+	   double goaly;
+	   double goalz;
+	   bool connected;
 	public Q_SLOTS:
-	   void updateAngle(QGeoPositionInfo);
-	   void updateView(QGraphicsObject*);
 	   Q_INVOKABLE double gangle();
 	   Q_INVOKABLE void regoal();
 	   Q_INVOKABLE double gx();
 	   Q_INVOKABLE double gy();
+	   Q_INVOKABLE double gz();
+	   Q_INVOKABLE bool con();
 	   Q_INVOKABLE QString gext();
-	signals:
-	   void goalEmitted(QVariant);
 };
\ No newline at end of file
